@@ -31,6 +31,11 @@
 
 #include "pcap-int.h"
 
+#ifdef __linux__
+#define LINUX_PPP_FIX
+#include <linux/if_ppp.h>
+#endif
+
 static char snoop_device[255];
 struct ifreq ifr_orig;
 
@@ -57,14 +62,22 @@ int pcap_read(pcap_t *p, int cnt, pcap_handler callback, u_char *user)
   char *buf;
   int bufsize;
 
-  if (p->linktype == DLT_SLIP) {
-    buf = (char *)p->buffer+16;
-    bufsize = p->bufsize - 16;
-    memset(p->buffer,0,16);
-  } else if (p->linktype == DLT_PPP || p->linktype == DLT_NULL) {
+  if (p->linktype == DLT_NULL) {
     buf = (char *)p->buffer+4;
     bufsize = p->bufsize - 4;
     memset(p->buffer,0,4);
+  } else if (p->linktype == DLT_SLIP) {
+    buf = (char *)p->buffer+16;
+    bufsize = p->bufsize - 16;
+    memset(p->buffer,0,16);
+  } else if (p->linktype == DLT_PPP) {
+    buf = (char *)p->buffer+4;
+    bufsize = p->bufsize - 4;
+    memset(p->buffer,0,4);
+#ifdef LINUX_PPP_FIX
+    p->buffer[3] = PPP_IP;          /* work around for a linux bug
+                                           (no protocol entry) */
+#endif
   } else {
     buf = (char *)p->buffer;
     bufsize = p->bufsize;
@@ -78,6 +91,8 @@ int pcap_read(pcap_t *p, int cnt, pcap_handler callback, u_char *user)
       switch (errno) {
 	case EWOULDBLOCK:
 	  return (0);
+	case EINTR:
+	  continue;
       }
       sprintf(p->errbuf, "read: %s", pcap_strerror(errno));
       return (-1);
@@ -137,6 +152,9 @@ pcap_open_live(char *device, int snaplen, int promisc, int to_ms, char *ebuf)
   if (strncmp("et", device, 2) == 0) {
     p->linktype = DLT_EN10MB;
     has_promisc = 1;
+  } else if (strncmp("isdn", device, 4) == 0) {
+    p->linktype = DLT_RAWIP;
+    has_promisc = 1;
   } else if (strncmp("sl", device, 2) == 0)
     p->linktype = DLT_SLIP;
   else if (strncmp("ppp", device, 3) == 0)
