@@ -42,9 +42,9 @@ static char rcsid[] =
 #endif
 #include <rpc/types.h>
 #include <rpc/auth.h>
-#include <rpc/xdr.h> /* needs to be before auth_unix on linux*/
 #include <rpc/auth_unix.h>
 #include <rpc/svc.h>
+#include <rpc/xdr.h>
 #include <rpc/rpc_msg.h>
 
 #include <ctype.h>
