@@ -132,6 +132,9 @@ rtp_print(const void *hdr, int len, register const struct udphdr *up)
 #define NTP_PORT 123		/*XXX*/
 #define SNMPTRAP_PORT 162	/*XXX*/
 #define RIP_PORT 520		/*XXX*/
+#define NETBIOS_NS_PORT   137
+#define NETBIOS_DGRAM_PORT   138
+
 
 void
 udp_print(register const u_char *bp, int length, register const u_char *bp2)
@@ -249,6 +252,14 @@ udp_print(register const u_char *bp, int length, register const u_char *bp2)
 			ntp_print((const u_char *)(up + 1), length);
 		else if (dport == 3456)
 			vat_print((const void *)(up + 1), length, up);
+		else if (ISPORT(NETBIOS_NS_PORT)) {
+			unsigned char *data = (unsigned char *)(up + 1);
+			nbt_udp137_print(data,data+length>snapend?snapend:data+length);
+		}
+		else if (ISPORT(NETBIOS_DGRAM_PORT)) {
+			unsigned char *data = (unsigned char *)(up + 1);
+			nbt_udp138_print(data,data+length>snapend?snapend:data+length);
+		}
 		/*
 		 * Kludge in test for whiteboard packets.
 		 */
